#
# spec file for package forkstat
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           forkstat
Version:        0.03.01
Release:        1.2
Summary:        Process fork/exec/exit monitoring tool
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/ColinIanKing/forkstat
Source:         https://github.com/ColinIanKing/forkstat/archive/refs/tags/V%{version}.tar.gz#/%{name}-%{version}.tar.gz

%description
Forkstat monitors process fork(), exec() and exit() activity. It is useful for
monitoring system behaviour and to track down rogue processes that are spawning
off processes and potentially abusing the system.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (forkstat and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%{_bindir}/forkstat
%{_mandir}/man8/forkstat.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.03.01:
  * Makefile: bump version
  * debian/control: update standards version to 4.6.2
  * Manual: update copyright
  * forkstat: add -p process group id filtering option
  * forkstat: handle empty arg in argv[], replace with ' '
  * forkstat: make cmdline buffer 64K, allocate on heap
* Sun Jan 22 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.03.00
  * Remove redundant null check on ptr
  * Update copyright
  * forkstat: remove redundant assignment to ptr
  * Add STAT_NONE to event_t enum and use it instead of 0
* Sat Nov  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.16
  * forkstat: handle weird comm field in /proc/$PID/stat
  * conditionally build in helper functions
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.02.15:
  * add missing memory initialization to zero
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Sat Feb 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.14
  * Add effictive user id (EUID) for -x option
- Supplement against bash-completion, not bash
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.13
  * Add bash completion
* Sun Dec 15 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.12
  * Remove no-op free_proc_comm call on an unknown comm field
  * Return no info rather than NULL if proc_info_get returns NULL
  * Re-work unknown cmdline information
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.11
  * fix off-by-one end of string strncpy bug in tty name copying
* Sun Jul  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.10
  * Fix spelling mistake in manual
  * Update copyright year
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 0.02.09
  * Manual: update date
  * Add -X option, fix up short getopts help with missing options
  * forkstat: add in -c option in help info
- Update to version 0.02.08
  * Reduce scope of pointer ptr
  * Use unsigned int for %%u format specifiers
  * Add -c comm field info, also track comm field changes in proc info
- Update to version 0.02.07
  * remove '\r' and '\n' from command line process name
- Update to version 0.02.06
  * Add some extra paranoid clearing of tty and strncpy length,
    fixes potential buffer overrun
  * Add caching of dev to tty name lookup to fix expensive lookups
  * Add caching of uid to name lookup, print username rather than uids
    to fix expensive lookups
  * forkstat: pack structs a little more efficiently to save memory
* Fri Jul 13 2018 mardnh@gmx.de
- Update to version 0.02.05
  * Makefile: bump version
  * Manual, change -e all to -E in example to show alternate form
  * Reformat some lines, comments and overly wide scanf
  * Minor code clean ups
  * Ensure all fields in no_info are initialized
  * Manual: Fix process table information formatting
  * Voidify function returns
  * Add more constifications
  * Add -E (enable all events) option
  * PROC_EVENT_COREDUMP has been introduced in kernel version 3.10
  * Replace curved corner glyph with square corner
* Wed Jul 11 2018 mardnh@gmx.de
- Update to version 0.02.04
  * Makefile: bump version
  * Add .travis.yml to make dist rule
  * Makefile + debian/watch: produce a .xz tarball
  * Fix checking on zero sized reads
  * Add detection of first time all alive processes were started
  * Use UTF-16 codes for glyphs
  * Add travis build yaml file
* Sat Jun  9 2018 mardnh@gmx.de
- Update to version 0.02.03
  * Makefile: bump version
  * debian/control: update debhelper to >= 11
  * debian/compat: update to 11
  * debian/copyright: replace http with https for secure URL
  * debian/control: remove trailing line
  * Add -g option to mini-help
  * Add -g glyph annotations
  * Add faster container check for systemd based systems
  * Add snapcraft plugins
* Wed Jan 31 2018 mardnh@gmx.de
- update to version 0.02.02
  * Makefile: bump version
  * ensure tty string never overflows, fixes gcc warning
  * include <sys/uio.h> to fix clang warning
  * Add -x option into mini help
* Fri Jan  5 2018 mardnh@gmx.de
- update to version 0.02.01
  * Makefile: bump version
  * debian/control: update Standards-Version to 4.1.2
  * ensure tty string never overflows, fixes gcc warning
  * include <sys/uio.h> to fix clang warning
  * Add -x option into mini help
* Sun Jun 25 2017 mardnh@gmx.de
- update to version 0.02.00
  * Makefile: update version and change codename
  * Minor tweaks to the manual, cosmetic changes
  * Move arrays to end of stacks to help avoid any stack smashing
  * Minor source clean-up
  * Avoid TOCTOU race on stat + open
  * Use alternative ptrace pid info
  * Add -x extra UID and TTY information option
  * Add uid/sid event tracing
  * Display name of events on -e option when invalid event used
  * Add ptrace event spying
  * Fix realtime flag opts mask
  * Fix -r help option
  * Add extra spacing in heading as it is offset by one after PID
  * Remove old set_priority code now that -r replaces it
  * Manpage: fix pdf warning:
  * Makefile: add pdf man page rule and add .PHONEYs
  * Add Philipp Gesang to the man page for kudos for contributions.
  * Add -r real time scheduling option
  * Put help options into one large printf statement
* Thu Jun 22 2017 mardnh@gmx.de
- update to version 0.01.19
  * Makefile: bump version again
  * Debian/control: update standards version to 4.0.0
  * Update man page date
  * forkstat: add flag for line buffered output
* Tue Jun 20 2017 mardnh@gmx.de
- update to version 0.01.18
  * Makefile: bump version
  * Only add proc_info if strtol parses pid correctly.
  * snapcraft: add default type and grade keys
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.01.17
  * Makefile: bump version
  * Manual: update copyright year and manual date
  * Makefile: add snapcraft to make dist rule
  * Add variable pid size handling.
  * Remove redundant free on a null pointer
  * Add snapcraft
  * Update copyright year
  * Manual: expand width of columns to 5i
- update to version 0.01.16
  * Makefile: bump version
  * Make kernel_tasks const
  * unconstify arg in parse_ev to fix pedantic build warning
  * Clean up formatting on ev_map table
  * constify s1 and s2
  * Makefile: add PEDANTIC build flags
- update to version 0.01.15
  * Makefile: bump version
  * forkstat: make counters size_t
  * forkstat: voidify return from fclose
  * Debian: fix spelling mistake in changelog
- update to version 0.01.14
  * Makefile: bump version
  * debian/control: update Standards-Version to 3.9.8
  * debian/rules: make build reproducible (Closes: #833439)
  * Update copyright year to 2016
* Thu Feb 18 2016 mardnh@gmx.de
- update to 0.01.13
- upstream does not provide a changelog
* Thu Nov 12 2015 mardnh@gmx.de
- update to 0.01.12
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
